==> choochoo-0.20.1-py3-none-any.whl: tests/test_activities.py <==
from subprocess import run
from tempfile import NamedTemporaryFile
from unittest import TestCase

from sqlalchemy.sql.functions import count

from ch2.commands.activities import activities
from ch2.commands.args import bootstrap_file, m, V, DEV, mm, FAST
from ch2.commands.constants import constants
from ch2.config.default import default
from ch2.squeal.tables.activity import ActivityJournal
from ch2.squeal.tables.pipeline import PipelineType
from ch2.squeal.tables.statistic import StatisticJournal, StatisticJournalFloat, StatisticName
from ch2.stoats.names import RAW_ELEVATION, ELEVATION, ACTIVE_DISTANCE, ACTIVE_TIME
from ch2.stoats.pipeline import run_pipeline


class TestActivities(TestCase):

    def test_activities(self):

        with NamedTemporaryFile() as f:

            args, db = bootstrap_file(f, m(V), '5')

            bootstrap_file(f, m(V), '5', mm(DEV), configurator=default)

            args, db = bootstrap_file(f, m(V), '5', 'constants', '--set', 'FTHR.%', '154')
            constants(args, db)

            args, db = bootstrap_file(f, m(V), '5', 'constants', 'FTHR.%')
            constants(args, db)

            args, db = bootstrap_file(f, m(V), '5', 'constants', '--set', 'SRTM1.dir',
                                           '/home/andrew/archive/srtm1')
            constants(args, db)

            args, db = bootstrap_file(f, m(V), '5', mm(DEV),
                                           'activities', mm(FAST),
                                      'data/test/source/personal/2018-08-27-rec.fit')
            activities(args, db)

            # run('sqlite3 %s ".dump"' % f.name, shell=True)

            run_pipeline(db, PipelineType.STATISTIC, force=True, start='2018-01-01')

            # run('sqlite3 %s ".dump"' % f.name, shell=True)

            with db.session_context() as s:
                n_raw = s.query(count(StatisticJournalFloat.id)). \
                    join(StatisticName). \
                    filter(StatisticName.name == RAW_ELEVATION).scalar()
                self.assertEqual(2099, n_raw)
                n_fix = s.query(count(StatisticJournalFloat.id)). \
                    join(StatisticName). \
                    filter(StatisticName.name == ELEVATION).scalar()
                self.assertEqual(2099, n_fix)
                n = s.query(count(StatisticJournal.id)).scalar()
                # self.assertEqual(29876, n)
                # self.assertEqual(29865, n)  # why has this dropped slightly?
                self.assertEqual(25493, n)  # why has this dropped?
                journal = s.query(ActivityJournal).one()
                self.assertNotEqual(journal.start, journal.finish)

    def test_segment_bug(self):
        with NamedTemporaryFile() as f:
            rgs, db = bootstrap_file(f, m(V), '5', mm(DEV), configurator=default)
            paths = ['/home/andrew/archive/fit/bike/2016-07-27-pm-z4.fit']
            run_pipeline(db, PipelineType.ACTIVITY, paths=paths, force=True)

    def __assert_basic_stats(self, s):
        for name in [ACTIVE_DISTANCE, ACTIVE_TIME]:
            stat = s.query(StatisticJournal). \
                join(StatisticName). \
                filter(StatisticName.name == name).one_or_none()
            print(f'{name} = {stat}')
            self.assertTrue(stat, f'No value for {name}')

    def test_florian(self):
        with NamedTemporaryFile() as f:
            bootstrap_file(f, m(V), '5')
            bootstrap_file(f, m(V), '5', mm(DEV), configurator=default)
            args, db = bootstrap_file(f, m(V), '5', mm(DEV),
                                      'activities', mm(FAST),
                                      'data/test/source/private/florian.fit')
            activities(args, db)
            # run('sqlite3 %s ".dump"' % f.name, shell=True)
            run_pipeline(db, PipelineType.STATISTIC, n_cpu=1)
            # run('sqlite3 %s ".dump"' % f.name, shell=True)
            with db.session_context() as s:
                self.__assert_basic_stats(s)

    def test_michael(self):
        with NamedTemporaryFile() as f:
            bootstrap_file(f, m(V), '5')
            bootstrap_file(f, m(V), '5', mm(DEV), configurator=default)
            args, db = bootstrap_file(f, m(V), '5', mm(DEV),
                                      'activities', mm(FAST),
                                      'data/test/source/other/2019-05-09-051352-Running-iWatchSeries3.fit')
            activities(args, db)
            # run('sqlite3 %s ".dump"' % f.name, shell=True)
            run_pipeline(db, PipelineType.STATISTIC, n_cpu=1)
            # run('sqlite3 %s ".dump"' % f.name, shell=True)
            with db.session_context() as s:
                self.__assert_basic_stats(s)

==> choochoo-0.27.2-py3-none-any.whl: tests/test_activities.py <==

from subprocess import run
from tempfile import NamedTemporaryFile
from unittest import TestCase

from sqlalchemy.sql.functions import count

from ch2.commands.activities import activities
from ch2.commands.args import bootstrap_file, m, V, DEV, mm, FAST
from ch2.commands.constants import constants
from ch2.config.default import default
from ch2.squeal.tables.activity import ActivityJournal
from ch2.squeal.tables.pipeline import PipelineType
from ch2.squeal.tables.statistic import StatisticJournal, StatisticJournalFloat, StatisticName
from ch2.stoats.names import RAW_ELEVATION, ELEVATION, ACTIVE_DISTANCE, ACTIVE_TIME
from ch2.stoats.pipeline import run_pipeline


class TestActivities(TestCase):

    def test_activities(self):

        with NamedTemporaryFile() as f:

            args, db = bootstrap_file(f, m(V), '5')

            bootstrap_file(f, m(V), '5', mm(DEV), configurator=default)

            args, db = bootstrap_file(f, m(V), '5', 'constants', '--set', 'FTHR.%', '154')
            constants(args, db)

            args, db = bootstrap_file(f, m(V), '5', 'constants', 'FTHR.%')
            constants(args, db)

            args, db = bootstrap_file(f, m(V), '5', 'constants', '--set', 'SRTM1.dir',
                                      '/home/andrew/archive/srtm1')
            constants(args, db)

            args, db = bootstrap_file(f, m(V), '5', mm(DEV), 'activities', mm(FAST),
                                      'data/test/source/personal/2018-08-27-rec.fit')
            activities(args, db)

            # run('sqlite3 %s ".dump"' % f.name, shell=True)

            run_pipeline(db, PipelineType.STATISTIC, force=True, start='2018-01-01', n_cpu=1)

            # run('sqlite3 %s ".dump"' % f.name, shell=True)

            with db.session_context() as s:
                n_raw = s.query(count(StatisticJournalFloat.id)). \
                    join(StatisticName). \
                    filter(StatisticName.name == RAW_ELEVATION).scalar()
                self.assertEqual(2099, n_raw)
                n_fix = s.query(count(StatisticJournalFloat.id)). \
                    join(StatisticName). \
                    filter(StatisticName.name == ELEVATION).scalar()
                self.assertEqual(2099, n_fix)
                n = s.query(count(StatisticJournal.id)).scalar()
                self.assertEqual(23655, n)
                journal = s.query(ActivityJournal).one()
                self.assertNotEqual(journal.start, journal.finish)

    def test_segment_bug(self):
        with NamedTemporaryFile() as f:
            args, db = bootstrap_file(f, m(V), '5', mm(DEV), configurator=default)
            paths = ['/home/andrew/archive/fit/bike/2016-07-27-pm-z4.fit']
            run_pipeline(db, PipelineType.ACTIVITY, paths=paths, force=True)

    def __assert_basic_stats(self, s):
        for name in [ACTIVE_DISTANCE, ACTIVE_TIME]:
            stat = s.query(StatisticJournal). \
                join(StatisticName). \
                filter(StatisticName.name == name).one_or_none()
            print(f'{name} = {stat}')
            self.assertTrue(stat, f'No value for {name}')

    def test_florian(self):
        with NamedTemporaryFile() as f:
            bootstrap_file(f, m(V), '5')
            bootstrap_file(f, m(V), '5', mm(DEV), configurator=default)
            args, db = bootstrap_file(f, m(V), '5', mm(DEV),
                                      'activities', mm(FAST),
                                      'data/test/source/private/florian.fit')
            activities(args, db)
            # run('sqlite3 %s ".dump"' % f.name, shell=True)
            run_pipeline(db, PipelineType.STATISTIC, n_cpu=1)
            # run('sqlite3 %s ".dump"' % f.name, shell=True)
            with db.session_context() as s:
                self.__assert_basic_stats(s)

    def test_michael(self):
        with NamedTemporaryFile() as f:
            bootstrap_file(f, m(V), '5')
            bootstrap_file(f, m(V), '5', mm(DEV), configurator=default)
            args, db = bootstrap_file(f, m(V), '5', mm(DEV),
                                      'activities', mm(FAST),
                                      'data/test/source/other/2019-05-09-051352-Running-iWatchSeries3.fit')
            activities(args, db)
            # run('sqlite3 %s ".dump"' % f.name, shell=True)
            run_pipeline(db, PipelineType.STATISTIC, n_cpu=1)
            # run('sqlite3 %s ".dump"' % f.name, shell=True)
            with db.session_context() as s:
                self.__assert_basic_stats(s)

    def test_heart_alarms(self):
        with NamedTemporaryFile() as f:
            bootstrap_file(f, m(V), '5')
            bootstrap_file(f, m(V), '5', mm(DEV), configurator=default)
            args, db = bootstrap_file(f, m(V), '5', mm(DEV),
                                      'activities', mm(FAST),
                                      'data/test/source/personal/2016-07-19-mpu-s-z2.fit')
            activities(args, db)
            # run('sqlite3 %s ".dump"' % f.name, shell=True)
            run_pipeline(db, PipelineType.STATISTIC, n_cpu=1)
            # run('sqlite3 %s ".dump"' % f.name, shell=True)
            with db.session_context() as s:
                stat = s.query(StatisticJournal). \
                    join(StatisticName). \
                    filter(StatisticName.name == ACTIVE_DISTANCE).one()
                self.assertGreater(stat.value, 30000)

    def test_920(self):
        for src in '920xt-2019-05-16_19-42-54.fit', '920xt-2019-05-16_19-42-54.fit':
            with NamedTemporaryFile() as f:
                bootstrap_file(f, m(V), '5')
                bootstrap_file(f, m(V), '5', mm(DEV), configurator=default)
                args, db = bootstrap_file(f, m(V), '5', mm(DEV), 'activities', mm(FAST),
                                          f'data/test/source/other/{src}')
                activities(args, db)
                # run('sqlite3 %s ".dump"' % f.name, shell=True)
                run_pipeline(db, PipelineType.STATISTIC, n_cpu=1)
                # run('sqlite3 %s ".dump"' % f.name, shell=True)
                with db.session_context() as s:
                    self.__assert_basic_stats(s)
